This is a simple package to help you do univariate and bivariate analysis on numerc and categorical features. The visuals are generated using matplotlib and seaborn. The package is still in development and more features will be added soon. The usp is that in a single figure with subplots all the visuals are presented in a compact manner with a simple function call and passing the dataframe and a list of numeric or categorical features.
